==> fidelio_0.9.6.orig.tar.gz: fidelio-0.9.6/src/pixmap.h <==
#ifndef PIXMAP_H
#define PIXMAP_H

#define HL_MENU "Menu_"

#define HL_STOCK_PIXMAP_REFRESH    "HLRefresh"
#define HL_STOCK_PIXMAP_CONNECT    "HLConnect"
#define HL_STOCK_PIXMAP_CANCEL_ALL "HLCancelAll"
#define HL_STOCK_PIXMAP_CLOSE      "HLClose"

#define HL_STOCK_PIXMAP_TRACKERS "HLTrackers"

#define HL_STOCK_PIXMAP_DELETE   "HLDelete"
#define HL_STOCK_PIXMAP_INFO     "HLInfo"
#define HL_STOCK_PIXMAP_REPLY    "HLReply"
#define HL_STOCK_PIXMAP_NEWS_POST   "HLNPost"
#define HL_STOCK_PIXMAP_NEWS_PARENT "HLNParent"
#define HL_STOCK_PIXMAP_NEWS_CHILD  "HLNChild"
#define HL_STOCK_PIXMAP_NEWS_PREV   "HLNPrev"
#define HL_STOCK_PIXMAP_NEWS_NEXT   "HLNNext"

#define HL_STOCK_PIXMAP_BROADCAST "HLBroadcast"

#define HL_STOCK_PIXMAP_BOOKMARKS     "HLBookmarks"
#define HL_STOCK_PIXMAP_NEW_BOOKMARK  "HLNewBookmark"
#define HL_STOCK_PIXMAP_PROP_BOOKMARK "HLPropBookmark"
#define HL_STOCK_PIXMAP_BOOKMARK_FOLDER  "HLFolderBookmark"

#define HL_STOCK_PIXMAP_USERS     "HLUsers"
#define HL_STOCK_PIXMAP_FILES     "HLFiles"
#define HL_STOCK_PIXMAP_AGREEMENT "HLAgreement"
#define HL_STOCK_PIXMAP_NEWS      "HLNews"
#define HL_STOCK_PIXMAP_CHAT      "HLChat"
#define HL_STOCK_PIXMAP_PRIVCHAT  "HLPrivChat"

#define HL_STOCK_PIXMAP_USERS_SENDMESG "HLSendMessage"
#define HL_STOCK_PIXMAP_USERS_INFO     "HLUsersInfo"
#define HL_STOCK_PIXMAP_USERS_KICK     "HLUsersKick"


#define HL_STOCK_PIXMAP_DOWNLOAD "HLDownload"
#define HL_STOCK_PIXMAP_UPLOAD   "HLUpload"
#define HL_STOCK_PIXMAP_TRASH    "HLTrash"
#define HL_STOCK_PIXMAP_DIR_UP   "HLDirUp"

#define HL_STOCK_PIXMAP_CLOSE_PAGE "HLClose"
#define HL_STOCK_PIXMAP_FILES_PARENT "HLFilesParent"
#define HL_STOCK_PIXMAP_FILE_INFO  "HLFileInfo"
#define HL_STOCK_PIXMAP_FOLDER_NEW "HLFolderNew"

void pixmap_init(void);
void pixmap_get(char *name,GdkPixmap **pix,GdkBitmap **mask);


#endif

==> fidelio-1.0b1.tar.gz: fidelio-1.0b1/src/pixmap.h <==
#ifndef PIXMAP_H
#define PIXMAP_H

#define HL_MENU "Menu_"

#define HL_STOCK_PIXMAP_REFRESH    "HLRefresh"
#define HL_STOCK_PIXMAP_CONNECT    "HLConnect"
#define HL_STOCK_PIXMAP_CANCEL_ALL "HLCancelAll"
#define HL_STOCK_PIXMAP_CLOSE      "HLClose"

#define HL_STOCK_PIXMAP_TRACKERS "HLTrackers"

#define HL_STOCK_PIXMAP_DELETE   "HLDelete"
#define HL_STOCK_PIXMAP_INFO     "HLInfo"
#define HL_STOCK_PIXMAP_REPLY    "HLReply"
#define HL_STOCK_PIXMAP_NEWS_POST   "HLNPost"
#define HL_STOCK_PIXMAP_NEWS_PARENT "HLNParent"
#define HL_STOCK_PIXMAP_NEWS_CHILD  "HLNChild"
#define HL_STOCK_PIXMAP_NEWS_PREV   "HLNPrev"
#define HL_STOCK_PIXMAP_NEWS_NEXT   "HLNNext"

#define HL_STOCK_PIXMAP_BROADCAST "HLBroadcast"

#define HL_STOCK_PIXMAP_BOOKMARKS     "HLBookmarks"
#define HL_STOCK_PIXMAP_NEW_BOOKMARK  "HLNewBookmark"
#define HL_STOCK_PIXMAP_PROP_BOOKMARK "HLPropBookmark"
#define HL_STOCK_PIXMAP_BOOKMARK_FOLDER  "HLFolderBookmark"

#define HL_STOCK_PIXMAP_USERS     "HLUsers"
#define HL_STOCK_PIXMAP_FILES     "HLFiles"
#define HL_STOCK_PIXMAP_AGREEMENT "HLAgreement"
#define HL_STOCK_PIXMAP_NEWS      "HLNews"
#define HL_STOCK_PIXMAP_CHAT      "HLChat"
#define HL_STOCK_PIXMAP_PRIVCHAT  "HLPrivChat"

#define HL_STOCK_PIXMAP_USERS_SENDMESG "HLSendMessage"
#define HL_STOCK_PIXMAP_USERS_INFO     "HLUsersInfo"
#define HL_STOCK_PIXMAP_USERS_KICK     "HLUsersKick"
#define HL_STOCK_PIXMAP_USER_DONT_MSG  "HLDontMsg"
#define HL_STOCK_PIXMAP_USER_DONT_CHAT "HLDontChat"

#define HL_STOCK_PIXMAP_DOWNLOAD "HLDownload"
#define HL_STOCK_PIXMAP_UPLOAD   "HLUpload"
#define HL_STOCK_PIXMAP_TRASH    "HLTrash"
#define HL_STOCK_PIXMAP_DIR_UP   "HLDirUp"

#define HL_STOCK_PIXMAP_CLOSE_PAGE "HLClose"
#define HL_STOCK_PIXMAP_FILES_PARENT "HLFilesParent"
#define HL_STOCK_PIXMAP_FILE_INFO  "HLFileInfo"
#define HL_STOCK_PIXMAP_FILE_TRANSFER_GREENLIGHT  "HLFileStartTransfer"
#define HL_STOCK_PIXMAP_FOLDER_NEW "HLFolderNew"

void pixmap_init(void);
void pixmap_get(char *name,GdkPixmap **pix,GdkBitmap **mask);
void pixmap_apply_to_widget(char * name,GtkPixmap *pixm);
char *pixmap_ensure_stock_icon_number(int num);
GtkWidget *pixmap_stock_new_for_icon(int num);


#endif
